/*
 * Copyright 2009 SpringSource
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.bundlor.ant;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import java.util.Arrays;
import java.util.List;

import org.apache.tools.ant.BuildException;
import org.junit.Test;

public class BundlorTests {

    private final StubBundlor bundlor = new StubBundlor();

    @Test
    public void executeDisabled() {
        this.bundlor.setEnabled(false);
        this.bundlor.execute();
        assertFalse(bundlor.getStubBundlorExecutor().getCalled());
    }

    @Test
    public void executeDontFailOnWarnings() {
        this.bundlor.execute();
        assertTrue(bundlor.getStubBundlorExecutor().getCalled());
    }

    @Test(expected = BuildException.class)
    public void executeFailOnWarnings() {
        this.bundlor.setFailOnWarnings(true);
        this.bundlor.execute();
    }

    @Test(expected = BuildException.class)
    public void executeFailOnWarningsWithMaifestTemplatePath() {
        this.bundlor.setFailOnWarnings(true);
        this.bundlor.setManifestTemplatePath("test");
        this.bundlor.execute();
    }

    private static class StubBundlor extends Bundlor {

        private final StubBundlorExecutor executor = new StubBundlorExecutor();

        @Override
        protected BundlorExecutor getBundlorExecutor() {
            return this.executor;
        }

        public StubBundlorExecutor getStubBundlorExecutor() {
            return this.executor;
        }

    }

    private static class StubBundlorExecutor implements BundlorExecutor {

        private volatile boolean called = false;

        public List<String> execute() {
            this.called = true;
            return Arrays.asList("warning");
        }

        public boolean getCalled() {
            return this.called;
        }
    }
}
